const assert = require('assert'),
      suite = require('testingey').createSuite('fakedb'),
      db = require('../lib/fakedb').init('synch-test.fdb');

db.on('load', function () {

  var currentMax = 0,
      recordLimit = 1000;

  suite.setUp(function () {
    
    // create your index first before adding docs
    db.key('index', numeric = true);
    
    // add a thousand records
    for (currentMax = 0; currentMax < recordLimit; ++currentMax) {
      db.add({ index: currentMax, value: currentMax*currentMax });
    }
  });

  suite.tearDown(function () {
    db.purge();
  });

  suite.spec('Testing db.add()', function () {
    var current = db.count();
    db.add({ index: currentMax, value: currentMax*currentMax });
    assert.equal(db.count(), current + 1);
    currentMax++;
  });

  suite.spec('Testing db.del()', function () {
    
    var doc = { index: currentMax, value: currentMax*currentMax },
        key = db.add(doc);

    db.del(key);
    assert.equal(db.get(key), undefined);

    var all = db.all({ where: { index: currentMax } });
    assert.equal(all.length, 0);
  });

  suite.spec('Testing db.get()', function () {
    var doc = { index: currentMax, value: currentMax*currentMax },
        key = db.add(doc),
        obj = db.get(key);
    assert.deepEqual(obj.doc, doc);
    currentMax++;
  });

  suite.spec('Testing db.all() with no argument', function () {
    var current = db.count();
    var records = db.all();
    assert.equal(records.length, current);
  });

  suite.spec('Testing db.all() with query params', function () {
    var records = db.all({ where: { index: 3 } });
    assert.ok(records);
    assert.equal(records.length, 1);
    assert.deepEqual(records[0].doc, { index: 3, value: 9 });
  });

  suite.spec('Testing db.all() with callback filter', function () {
    var records = db.all(function (obj) {
      return (obj.doc.index && obj.doc.index < 5);
    });
    assert.ok(records);
    assert.equal(records.length, 4);
  });

  suite.spec('Testing db.all() for pagination', function () {
    var records = db.all({
      where: function (obj) { return obj.doc.index > 100; },
      limit: 5,
      offset: 0
    });
    assert.equal(records.length, 5);
    records = db.all({ limit: 10, offset: 0 });
    assert.equal(records.length, 10);
  });

  suite.spec('Testing db.purge()', function () {
    db.purge();
    assert.equal(db.count(), 0);
  });

  suite.run();

});
